==> mvvirtualdevice-x86-ABI1-1.10.49.127.tgz: mvimpact_acquire-x86-1.10.49.127/apps/mvPropView/DevCtrl.h <==
//-----------------------------------------------------------------------------
#ifndef DevCtrlH
#define DevCtrlH DevCtrlH
//-----------------------------------------------------------------------------
#include "DevData.h"
#include <map>
#include <mvIMPACT_CPP/mvIMPACT_acquire.h>
#include <string>
#include <wx/string.h>
#include <wx/thread.h>

class	CaptureThread;
class	PropData;
class	PropTree;
class	wxPropertyGrid;
class	wxWindow;

typedef std::map<mvIMPACT::acquire::Device*, DeviceData*> DevToTreeMap;

//-----------------------------------------------------------------------------
class DevicePropertyHandler
//-----------------------------------------------------------------------------
{
public:
	DevicePropertyHandler( wxPropertyGrid* pGrid, bool boDisplayDebugInfo, bool boDisplayFullTree, bool boDisplayInvisibleComponents, bool boShowEvents );
	~DevicePropertyHandler();
	enum TViewMode
	{
		vmStandard,
		vmDeveloper
	};
	void											CloseDriver( const wxString& name );
	mvIMPACT::acquire::Device*						GetActiveDevice( mvIMPACT::acquire::FunctionInterface** ppFI = 0, const mvIMPACT::acquire::Statistics** ppS = 0, CaptureThread** ppCT = 0, mvIMPACT::acquire::EventSubSystem** ppESS = 0 ) const;
	bool											GetDeviceData( mvIMPACT::acquire::Device* pDev, mvIMPACT::acquire::FunctionInterface** ppFI = 0, const mvIMPACT::acquire::Statistics** ppS = 0, CaptureThread** ppCT = 0, mvIMPACT::acquire::EventSubSystem** ppESS = 0 ) const;
	const mvIMPACT::acquire::DeviceManager&			GetDevMgr( void ) const { return m_devMgr; }
	TViewMode										GetViewMode( void ) const { return m_viewMode; }
	void											OpenDriver( const wxString& name, wxWindow* pParentWindow );
	void											SetActiveDevice( const wxString& name );
	void											SetViewMode( TViewMode mode );
	void											ValidateTrees( void );

private:
	unsigned int						m_actDevListChangedCounter;
	bool								m_boDisplayDebugInfo;
	bool								m_boDisplayInvisibleComponents;
	bool								m_boShowEvents;
	unsigned int						m_fullTreeChangedCounter;
	PropTree*							m_pFullTree;
	mvIMPACT::acquire::DeviceManager	m_devMgr;
	DevToTreeMap						m_devToTreeMap;
	const DeviceData*					m_pActiveDevData;
	mvIMPACT::acquire::Device*			m_pActiveDevice;
	wxPropertyGrid*						m_pPropertyGrid;
	mutable wxCriticalSection			m_critSect;
	TViewMode							m_viewMode;
	void								GetInterfaceClasses( const DeviceData* p, mvIMPACT::acquire::FunctionInterface** ppFI /* = 0 */, const mvIMPACT::acquire::Statistics** ppS /* = 0 */, CaptureThread** ppCT /* = 0 */, mvIMPACT::acquire::EventSubSystem** ppESS /* = 0 */ ) const;
	void								UpdateTreeMap( void );
	void								CreateDriverTrees( DevToTreeMap::iterator& it );
	void								DeleteDriverTrees( DevToTreeMap::iterator& it );
	void								PrepareTreeArray( void );

	struct TreeProp
	{	
		TreeProp( const std::string& listName, const std::string& displayedName ) : ListName(listName),
			DisplayName(displayedName), ChangedCounter(0), ListType(mvIMPACT::acquire::dltUndefined) {}
		TreeProp( mvIMPACT::acquire::TDeviceListType listType, const std::string& displayedName ) : ListName(""),
			DisplayName(displayedName), ChangedCounter(0), ListType(listType) {}
		std::string							ListName;
		std::string							DisplayName;
		unsigned int						ChangedCounter;
		mvIMPACT::acquire::TDeviceListType	ListType;
	};
	std::vector<TreeProp>	m_vTreeProps;
};

#endif // DevCtrlH

==> mvvirtualdevice-x86-ABI2-1.10.99.177.tgz: mvimpact_acquire-x86-1.10.99.177/apps/mvPropView/DevCtrl.h <==
//-----------------------------------------------------------------------------
#ifndef DevCtrlH
#define DevCtrlH DevCtrlH
//-----------------------------------------------------------------------------
#include "DevData.h"
#include <map>
#include <mvIMPACT_CPP/mvIMPACT_acquire.h>
#include <string>
#include <wx/string.h>
#include <wx/thread.h>

class	CaptureThread;
class	PropData;
class	PropTree;
class	wxPropertyGrid;
class	wxWindow;

typedef std::map<mvIMPACT::acquire::Device*, DeviceData*> DevToTreeMap;

//-----------------------------------------------------------------------------
class DevicePropertyHandler
//-----------------------------------------------------------------------------
{
public:
	DevicePropertyHandler( wxPropertyGrid* pGrid, bool boDisplayDebugInfo, bool boDisplayFullTree, bool boDisplayInvisibleComponents, bool boShowEvents );
	~DevicePropertyHandler();
	enum TViewMode
	{
		vmStandard,
		vmDeveloper
	};
	void											CloseDriver( const wxString& name );
	mvIMPACT::acquire::Device*						GetActiveDevice( mvIMPACT::acquire::FunctionInterface** ppFI = 0, const mvIMPACT::acquire::Statistics** ppS = 0, CaptureThread** ppCT = 0, mvIMPACT::acquire::EventSubSystem** ppESS = 0 ) const;
	bool											GetDeviceData( mvIMPACT::acquire::Device* pDev, mvIMPACT::acquire::FunctionInterface** ppFI = 0, const mvIMPACT::acquire::Statistics** ppS = 0, CaptureThread** ppCT = 0, mvIMPACT::acquire::EventSubSystem** ppESS = 0 ) const;
	const mvIMPACT::acquire::DeviceManager&			GetDevMgr( void ) const { return m_devMgr; }
	TViewMode										GetViewMode( void ) const { return m_viewMode; }
	void											OpenDriver( const wxString& name, wxWindow* pParentWindow );
	void											SetActiveDevice( const wxString& name );
	void											SetViewMode( TViewMode mode, bool boUseHexIndices );
	void											ValidateTrees( void );

private:
	unsigned int						m_actDevListChangedCounter;
	bool								m_boDisplayDebugInfo;
	bool								m_boDisplayInvisibleComponents;
	bool								m_boShowEvents;
	unsigned int						m_fullTreeChangedCounter;
	PropTree*							m_pFullTree;
	mvIMPACT::acquire::DeviceManager	m_devMgr;
	DevToTreeMap						m_devToTreeMap;
	const DeviceData*					m_pActiveDevData;
	mvIMPACT::acquire::Device*			m_pActiveDevice;
	wxPropertyGrid*						m_pPropertyGrid;
	mutable wxCriticalSection			m_critSect;
	TViewMode							m_viewMode;
	bool								m_boUseHexIndices;
	void								GetInterfaceClasses( const DeviceData* p, mvIMPACT::acquire::FunctionInterface** ppFI /* = 0 */, const mvIMPACT::acquire::Statistics** ppS /* = 0 */, CaptureThread** ppCT /* = 0 */, mvIMPACT::acquire::EventSubSystem** ppESS /* = 0 */ ) const;
	void								UpdateTreeMap( void );
	void								CreateDriverTrees( DevToTreeMap::iterator& it );
	void								DeleteDriverTrees( DevToTreeMap::iterator& it );
	unsigned int						GetDisplayFlags( void ) const;
	void								PrepareTreeArray( void );

	struct TreeProp
	{	
		TreeProp( const std::string& listName, const std::string& displayedName ) : ListName(listName),
			DisplayName(displayedName), ChangedCounter(0), ListType(mvIMPACT::acquire::dltUndefined) {}
		TreeProp( mvIMPACT::acquire::TDeviceListType listType, const std::string& displayedName ) : ListName(""),
			DisplayName(displayedName), ChangedCounter(0), ListType(listType) {}
		std::string							ListName;
		std::string							DisplayName;
		unsigned int						ChangedCounter;
		mvIMPACT::acquire::TDeviceListType	ListType;
	};
	std::vector<TreeProp>	m_vTreeProps;
};

#endif // DevCtrlH
